############################################################################################
#
# R Code to reproduce the analyses and figures in Data Colada [97],
# "Data Replicada #10: Does Goal Conflict Affect Time Spent on Work and Leisure?"
# Last update: 04-27-2021
# Author: Joe Simmons
# If you find any errors, or have any compatibility issues, please contact Joe at 
# jsimmo@upenn.edu
# This code uses R version 4.0.3.
#
############################################################################################
#
# Before You Begin:
#
# Set your working directory to be the folder in which you saved the data files.
setwd("file location")

# Load/install these libraries; using groundhog makes it work forever
library(groundhog)
groundhog.day="2021-02-01"
groundhog.library('numform', groundhog.day) # to format numbers
groundhog.library('pwr', groundhog.day) # to do power analysis
groundhog.library('emmeans', groundhog.day) # to do ANOVA with planned contrasts
groundhog.library('afex', groundhog.day) # to do ANOVA with planned contrasts

############################################################################################
#
# Outline:
# 1) Preparing The Datasets
#   1.1) Get The Replication Data
#   1.2) Get The Original Data
#   1.3) Create New Variables
#       1.3.1)  Winsorize Book Browsing Time Variable At 300 Seconds
#       1.3.2)  Natural Log Transformed Time Spent Book Browsing
#       1.3.3)  Goal Conflict Condition Variable
#       1.3.4)  Work/Leisure Condition Variable
#       1.3.5)  Whether They Passed First Attention Check
#       1.3.6)  Whether They Passed Second Attention Check
#       1.3.7)  Whether They Completed The Goal Task
#       1.3.8)  Whether They Completed The Goal Conflict Task
#       1.3.9)  Whether They Completed The Book Browsing Task
#       1.3.10)  Goal Conflict Manipulation Check
#       1.3.11)  How Many Books Were Clicked On
# 2) Exclusions
#   2.1) Make A Clean Version of the Datasets
#   2.2) Exclude Those Who Opened The Survey But Did Not Answer Any Questions
#   2.3) Exclude Those Who Failed First Attention Check (And Couldn't Proceed)
#   2.4) Exclude Those Who Did Not Complete The Goals Task
#   2.5) Exclude Those Who Did Not Complete The Goal Conflict Writing Task
#   2.6) Exclude Those Who Did Not Complete The Book Browsing Task
#   2.7) Exclude Those Who Did Not Submit The HIT For Payment
#   2.8) Exclude Those Who Did Not Complete Attention Check
#   2.9) Exclude Those Who Failed Attention Check
#   2.10) Exclude Those Associated With Duplicate MTurk IDs
#   2.11) Exclude Those Associated With Duplicate IP Addresses
#   2.12) Exclude Those Who Misreported Their MTurk ID
#   2.13) Exclude Those Who Spent More Than 30 Minutes On The Survey
#   2.14) Summary of Sample Sizes & Exclusions
#   2.15) Create Separate Datasets for the Work vs. Leisure Conditions
# 3) Functions
#   3.1) Function 1 - pooled.sd()         Compute the pooled standard deviation given
#                                         each group's sd and n
#   3.2) Function 2 - cohen.d()           Compute the independent groups Cohen's d given
#                                         the means, sds, and ns of each of two groups
#   3.3) Function 3 - error.bar()         Draw error bars on a graph
# 4) Conduct Main Analyses on Book Browsing Time Variable
#   4.1) Get Descriptive Statistics For Logged Book Browsing Time Variable
#   4.2) Get Descriptive Statistics For Raw Book Browsing Time Variable
#   4.3) Pre-registered Analyses Of Logged Book Browsing Time Variable
#   4.4) Regression Analyses On Logged Book Browsing Time Variable (Not Pre-registered)
#   4.5) Analyses Of Raw Book Browsing Time Variable (Not Pre-registered)
#   4.6) Regression Analyses On Raw Book Browsing Time Variable (Not Pre-registered)
# 5) Conduct Alternative Analyses Using ANOVA & Planned Contrasts (As In Original Study)
#   5.1) Analyze Replication 1
#   5.2) Analyze Replication 2
# 6) Conduct Analyses Of Manipulation Check
#   6.1) Get Descriptive Statistics
#   6.2) Goal Conflict x Work/Leisure Regression
# 7) Plotting the Book Browsing Time Results
#   7.1) Matrix of Means
#   7.2) Matrix of Standard Deviations
#   7.3) Matrix of Sample Sizes
#   7.4) Matrix of Standard Errors
#   7.5) Set Graph Parameters
#   7.6) Graph The Means
# 8) Conduct Exploratory Analyses of Number Of Books Variable
#   8.1) Get Descriptive Statistics For Number Of Books Variable
#   8.2) Exploratory Analyses Of Number of Books Variable
#   8.3) Regression Analyses On Book Number Variable
# 9) Conduct Analyses To Assess Required Sample Sizes and Implied Power
#   9.1) Matrix of Effect Sizes
#   9.2) Compute Required Sample Sizes Required To Detect Replication Effect Sizes
#   9.3) Compute Power of Original Study To Detect Replication Effect Sizes

############################################################################################
#
# 1) Preparing The Datasets
#   1.1) Get The Replication Data

# read data
d1 = read.csv("Etkin & Memmi 2020 Study 1a Rep 1 Data (De-identified).csv",
              stringsAsFactors = FALSE,header=TRUE)
d2 = read.csv("Etkin & Memmi 2020 Study 1a Rep 2 Data (De-identified).csv",
              stringsAsFactors = FALSE,header=TRUE)

#####

#   1.2) Create New Variables
#       1.2.1)  Winsorize Book Browsing Time Variable At 300 Seconds

# Note: We did not pre-register to do this in Replication 1, but the survey was
# programmed to auto-advance participants after 300 seconds. Somehow one participant -
# who reported technical difficulties - spent more than 400 seconds on the survey. Makes
# sense to cap at 300 seconds since the survey was programmed to disallow times longer
# than that. If you want to see the effects of this winsorizing, then un-comment the two
# lines below the ifelse code below.

d1$book_time_raw = ifelse(d1$timebrowse_Page.Submit>300,300,d1$timebrowse_Page.Submit)
d2$book_time_raw = ifelse(d2$timebrowse_Page.Submit>300,300,d2$timebrowse_Page.Submit)

#d1$book_time_raw = d1$timebrowse_Page.Submit
#d2$book_time_raw = d2$timebrowse_Page.Submit

###

#       1.2.2)  Natural Log Transformed Time Spent Book Browsing

d1$book_time = log(d1$book_time_raw)
d2$book_time = log(d2$book_time_raw)
d_orig$book_time = log(d_orig$book_time_raw)

###

#       1.2.3)  Goal Conflict Condition Variable

d1$goal_conflict = ifelse((d1$condition=="conflictXwork"|d1$condition=="conflictXleisure"),1,
                   ifelse((d1$condition=="NOconflictXwork"|d1$condition=="NOconflictXleisure"),0,NA))
d2$goal_conflict = ifelse((d2$condition=="conflictXwork"|d2$condition=="conflictXleisure"),1,
                   ifelse((d2$condition=="NOconflictXwork"|d2$condition=="NOconflictXleisure"),0,NA))
d_orig$goal_conflict = ifelse((d_orig$condition=="conflictXwork"|d_orig$condition=="conflictXleisure"),1,
                       ifelse((d_orig$condition=="NOconflictXwork"|d_orig$condition=="NOconflictXleisure"),0,NA))

###

#       1.2.4)  Work/Leisure Condition Variable

d1$work = ifelse((d1$condition=="conflictXwork"|d1$condition=="NOconflictXwork"),1,
          ifelse((d1$condition=="conflictXleisure"|d1$condition=="NOconflictXleisure"),0,NA))
d2$work = ifelse((d2$condition=="conflictXwork"|d2$condition=="NOconflictXwork"),1,
          ifelse((d2$condition=="conflictXleisure"|d2$condition=="NOconflictXleisure"),0,NA))
d_orig$work = ifelse((d_orig$condition=="conflictXwork"|d_orig$condition=="NOconflictXwork"),1,
              ifelse((d_orig$condition=="conflictXleisure"|d_orig$condition=="NOconflictXleisure"),0,NA))

###

#       1.2.5)  Whether They Passed First Attention Check

d1$passed_check1 = ifelse(d1$AC_1==1,1,0)
table(d1$passed_check1)

d2$passed_check1 = ifelse(d2$AC_1==1,1,0)
table(d2$passed_check1)

###

#       1.2.6)  Whether They Passed Second Attention Check

d1$passed_check2 = ifelse((d1$attck2==1|d1$attck2==4),1,
                          ifelse(is.na(d1$attck2),NA,0))
table(d1$passed_check2)

d2$passed_check2 = ifelse((d2$attck2==1|d2$attck2==4),1,
                          ifelse(is.na(d2$attck2),NA,0))
table(d2$passed_check2)

###

#       1.2.7)  Whether They Completed The Goal Task

d1$comp_goals = ifelse(is.na(d1$multgoals_time_Page.Submit),0,1)
table(d1$comp_goals,d1$condition)

d2$comp_goals = ifelse(is.na(d2$multgoals_time_Page.Submit),0,1)
table(d2$comp_goals,d2$condition)

###

#       1.2.8)  Whether They Completed The Goal Conflict Task

d1$comp_conf = ifelse(is.na(d1$conflict_time_Page.Submit),0,1)
table(d1$comp_conf,d1$condition)

d2$comp_conf = ifelse(is.na(d2$conflict_time_Page.Submit),0,1)
table(d2$comp_conf,d2$condition)

###

#       1.2.9)  Whether They Completed The Book Browsing Task

d1$comp_book = ifelse(is.na(d1$timebrowse_Page.Submit),0,1)
table(d1$comp_book,d1$condition)

d2$comp_book = ifelse(is.na(d2$timebrowse_Page.Submit),0,1)
table(d2$comp_book,d2$condition)

###

#       1.2.10)  Goal Conflict Manipulation Check

d1$manipck = (d1$mc1+d1$mc2+d1$mc3)/3
d2$manipck = (d2$mc1+d2$mc2+d2$mc3)/3

###

#       1.2.11)  How Many Books Were Clicked On

d1$num_books = rep(NA,nrow(d1))

for(i in 1:nrow(d1)) {
  
  d1$num_books[i] = length(strsplit(d1$titles[i],",")[[1]])
  
}


d2$num_books = rep(NA,nrow(d2))

for(i in 1:nrow(d2)) {
  
  d2$num_books[i] = length(strsplit(d2$titles[i],",")[[1]])
  
}


############################################################################################
#
# 2) Exclusions

#   2.1) Make A Clean Version of the Datasets

d1_clean = d1
table(d1_clean$condition)
d2_clean = d2
table(d2_clean$condition)

#####

#   2.2) Exclude Those Who Opened The Survey But Did Not Answer Any Questions

# remove 5 observations (who were never assigned to any condition)
d1_clean = d1_clean[!is.na(d1_clean$passed_check1),]
table(d1_clean$condition)

# remove 1 observation (who was never assigned to any condition)
d2_clean = d2_clean[!is.na(d2_clean$passed_check1),]
table(d2_clean$condition)

#####

#   2.3) Exclude Those Who Failed First Attention Check (And Couldn't Proceed)

# remove 11 observations (who were never assigned to any condition)
d1_clean = d1_clean[d1_clean$passed_check1==1,]
table(d1_clean$condition)

# remove 2 observations (who were never assigned to any condition)
d2_clean = d2_clean[d2_clean$passed_check1==1,]
table(d2_clean$condition)

#####

#   2.4) Exclude Those Who Did Not Complete The Goals Task

# remove 105 observations (14 from conflict/leisure; 14 from no-conflict/leisure;
#                          19 from conflict/work; 14 from no-conflict/work; 
#                          44 not assigned to any condition)
d1_clean = d1_clean[d1_clean$comp_goals==1,]
table(d1_clean$condition)

# remove 67 observations (7 from conflict/leisure; 5 from no-conflict/leisure;
#                         17 from conflict/work; 6 from no-conflict/work; 
#                         32 not assigned to any condition)
d2_clean = d2_clean[d2_clean$comp_goals==1,]
table(d2_clean$condition)

#####

#   2.5) Exclude Those Who Did Not Complete The Goal Conflict Writing Task

# remove 112 observations (19 from conflict/leisure; 40 from no-conflict/leisure;
#                          21 from conflict/work; 32 from no-conflict/work)
table(d1_clean$comp_conf)  # 8.2% of participants dropped out at this point
d1_clean = d1_clean[d1_clean$comp_conf==1,]
table(d1_clean$condition)

# remove 78 observations (18 from conflict/leisure; 21 from no-conflict/leisure;
#                         18 from conflict/work; 21 from no-conflict/work)
table(d2_clean$comp_conf)  # 6.0% of participants dropped out at this point
d2_clean = d2_clean[d2_clean$comp_conf==1,]
table(d2_clean$condition)

#####

#   2.6) Exclude Those Who Did Not Complete The Book Browsing Task

# remove 18 observations (4 from conflict/leisure; 9 from no-conflict/leisure;
#                         1 from conflict/work; 4 from no-conflict/work)
d1_clean = d1_clean[d1_clean$comp_book==1,]
table(d1_clean$condition)

# remove 6 observations (0 from conflict/leisure; 3 from no-conflict/leisure;
#                        2 from conflict/work; 1 from no-conflict/work)
d2_clean = d2_clean[d2_clean$comp_book==1,]
table(d2_clean$condition)

#####

#   2.7) Exclude Those Who Did Not Submit The HIT For Payment

# remove 21 observations (4 from conflict/leisure; 8 from no-conflict/leisure;
#                         3 from conflict/work; 6 from no-conflict/work)
d1_clean = d1_clean[d1_clean$paid==1,]
table(d1_clean$condition)

# remove 10 observations (1 from conflict/leisure; 3 from no-conflict/leisure;
#                         3 from conflict/work; 3 from no-conflict/work)
d2_clean = d2_clean[d2_clean$paid==1,]
table(d2_clean$condition)

#####

#   2.8) Exclude Those Who Did Not Complete Attention Check

# remove 7 observations (3 from conflict/leisure; 2 from no-conflict/leisure;
#                        2 from conflict/work; 0 from no-conflict/work)
d1_clean = d1_clean[!is.na(d1_clean$passed_check2),]
table(d1_clean$condition)

# remove 1 observation (1 from conflict/work)
d2_clean = d2_clean[!is.na(d2_clean$passed_check2),]
table(d2_clean$condition)

#####

#   2.9) Exclude Those Who Failed Attention Check

# remove 158 observations (35 from conflict/leisure; 41 from no-conflict/leisure;
#                          44 from conflict/work; 38 from no-conflict/work)
table(d1_clean$passed_check2)/sum(!is.na(d1_clean$passed_check2))  # 13.16% failed check
d1_clean = d1_clean[d1_clean$passed_check2==1,]
table(d1_clean$condition)

# remove 43 observations (9 from conflict/leisure; 8 from no-conflict/leisure;
#                         13 from conflict/work; 13 from no-conflict/work)
table(d2_clean$passed_check2)/sum(!is.na(d2_clean$passed_check2))  # 3.57% failed check
d2_clean = d2_clean[d2_clean$passed_check2==1,]
table(d2_clean$condition)

#####

#   2.10) Exclude Those Associated With Duplicate MTurk IDs

# remove 22 observations (7 from conflict/leisure; 3 from no-conflict/leisure;
#                         6 from conflict/work; 6 from no-conflict/work)
d1_clean = d1_clean[d1_clean$mturk_dup==0,]
table(d1_clean$condition)

# remove 13 observations (0 from conflict/leisure; 5 from no-conflict/leisure;
#                         6 from conflict/work; 2 from no-conflict/work)
d2_clean = d2_clean[d2_clean$mturk_dup==0,]
table(d2_clean$condition)

#####

#   2.11) Exclude Those Associated With Duplicate IP Addresses

# remove 0 observations
d1_clean = d1_clean[d1_clean$ip_dup==0,]
table(d1_clean$condition)

# remove 2 observations (1 from conflict/work; 1 from no-conflict/leisure)
d2_clean = d2_clean[d2_clean$ip_dup==0,]
table(d2_clean$condition)

#####

#   2.12) Exclude Those Who Misreported Their MTurk ID

# remove 12 observations (3 from conflict/leisure; 3 from no-conflict/leisure;
#                         0 from conflict/work; 6 from no-conflict/work)
d1_clean = d1_clean[d1_clean$mturk_match==1,]
table(d1_clean$condition)

# remove 17 observations (5 from conflict/leisure; 4 from no-conflict/leisure;
#                         7 from conflict/work; 1 from no-conflict/work)
d2_clean = d2_clean[d2_clean$mturk_match==1,]
table(d2_clean$condition)

#####

#   2.13) Exclude Those Who Spent More Than 30 Minutes On The Survey

# remove 1 observation (1 from no-conflict/leisure)
d1_clean = d1_clean[d1_clean$Duration..in.seconds.<1801,]
table(d1_clean$condition)

# remove 2 observations (2 from conflict/leisure)
d2_clean = d2_clean[d2_clean$Duration..in.seconds.<1801,]
table(d2_clean$condition)

#####

#   2.14) Summary of Sample Sizes & Exclusions

# Replication 1: N = 1,008 (266 in conflict/leisure (89 exclusions [25.1%]); 
#                           234 in no-conflict/leisure (121 exclusions [34.1%]);
#                           259 in conflict/work (96 exclusions [27.0%]);
#                           249 in no-conflict/work (106 exclusions [29.8%]);
#                            60 excluded who were never assigned to condition)

# Replication 2: N = 1,127 (291 in conflict/leisure (42 exclusions [12.6%]); 
#                           284 in no-conflict/leisure (50 exclusions [15.0%]);
#                           266 in conflict/work (68 exclusions [20.4%]);
#                           286 in no-conflict/work (106 exclusions [14.1%]);
#                            35 excluded who were never assigned to condition)
  
#####

#   2.15) Create Separate Datasets for the Work vs. Leisure Conditions

d1_work = d1_clean[d1_clean$work==1,]
d1_leisure = d1_clean[d1_clean$work==0,]

d2_work = d2_clean[d2_clean$work==1,]
d2_leisure = d2_clean[d2_clean$work==0,]

d_orig_work = d_orig[d_orig$work==1,]
d_orig_leisure = d_orig[d_orig$work==0,]

############################################################################################

# 3) Functions
#   3.1) Function 1 - pooled.sd()         Compute the pooled standard deviation given
#                                         each group's sd and n
pooled.sd <- function(sds,ns) {
  # takes in a vector of standard deviations and a vector of sample sizes and returns
  # the pooled standard deviation
  # inputs:
  #   sds: a vector of standard deviations
  #   ns: a vector of sample sizes
  
  # if the vector of sds is not the same length as the vector of ns, return
  # an error message
  if(length(sds)!=length(ns)) {   
    stop("Error: The sd vector and the sample size vector are not the same length")
  }
  
  # weigh the standard deviations by sample size
  weighted.sds <- rep(NA,times=length(sds))
  for(i in 1:length(sds)) {
    weighted.sds[i] <- (ns[i]-1)*sds[i]
  }
  
  # compute the pooled standard deviation
  result <- sum(weighted.sds)/(sum(ns)-length(sds))
  
  return(result)
}

#####

#   3.2) Function 2 - cohen.d()           Compute the independent groups Cohen's d given
#                                         the means, sds, and ns of each of two groups
cohen.d = function(means,sds,ns) {
  # takes in a vector of two means, a vector of two standard deviations, and a vector of 
  # two sample sizes and returns the cohen's d (assuming a two-group between subjects 
  # design)
  # inputs:
  #   means: a vector of two means
  #   sds: a vector of two standard deviations
  #   ns: a vector of two sample sizes
  
  # compute & print the mean difference
  mean.diff = means[1]-means[2]
  cat("\nMean Diff:",mean.diff)
  
  # compute & print the pooled standard deviation
  pooled_sd = pooled.sd(sds=sds,ns=ns)
  cat("\nPooled SD:",pooled_sd,"\n")
  
  # compute & return Cohen's d
  coh.d = mean.diff/pooled_sd
  return(coh.d)
}

#####

#   3.3) Function 3 - error.bar()         Draw error bars on a graph

error.bar <- function(x, y, upper, lower=upper, length=0.1,...){
  # Draw an error bar on graphs 
  # inputs:
  #   x: the plot to add the bars to
  #   y: the y-value at which the bars are centered (usually a vector of means)
  #   upper: a vector indicating how far up to draw the error bars
  #   lower: a vector indicating how far down to draw the error bars; defaulted to the
  #          same as upper
  #   length: how long the lines at the top and bottom of the error bars should be
  
  # make sure the two vectors are the same length
  if(length(x) != length(y) | length(y) !=length(lower) | length(lower) != length(upper))
    stop("vectors must be same length")
  
  # draw the error bars
  arrows(x, y+upper, x, y-lower, angle=90, code=3, length=length, ...)
}

############################################################################################
#
# 4) Conduct Main Analyses on Book Browsing Time Variable
#   4.1) Get Descriptive Statistics For Logged Book Browsing Time Variable

# Get the logged book browsing time means by condition
booktime_means1 = aggregate(x=d1_clean$book_time,
                            by=list(d1_clean$goal_conflict,d1_clean$work),
                                FUN=mean,na.rm=TRUE)
colnames(booktime_means1) = c("conflict_cond","work/leisure","means")
booktime_means1[,1] = rep(c("no-conflict","conflict"),2)
booktime_means1[,2] = c("leisure","leisure","work","work")
booktime_means1

booktime_means2 = aggregate(x=d2_clean$book_time,
                            by=list(d2_clean$goal_conflict,d2_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(booktime_means2) = c("conflict_cond","work/leisure","means")
booktime_means2[,1] = rep(c("no-conflict","conflict"),2)
booktime_means2[,2] = c("leisure","leisure","work","work")
booktime_means2

# original means shared by authors
booktime_means_orig = data.frame(data=c(rep(c("no-conflict","conflict"),2)),
                             c("leisure","leisure","work","work"),
                             c(4.014966,3.624468,3.601715,4.101236))
colnames(booktime_means_orig) = c("conflict_cond","work/leisure","means")
booktime_means_orig


# Get the logged book browsing time sds by condition
booktime_sds1 = aggregate(x=d1_clean$book_time,
                            by=list(d1_clean$goal_conflict,d1_clean$work),
                            FUN=sd,na.rm=TRUE)
colnames(booktime_sds1) = c("conflict_cond","work/leisure","sds")
booktime_sds1[,1] = rep(c("no-conflict","conflict"),2)
booktime_sds1[,2] = c("leisure","leisure","work","work")
booktime_sds1

booktime_sds2 = aggregate(x=d2_clean$book_time,
                          by=list(d2_clean$goal_conflict,d2_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(booktime_sds2) = c("conflict_cond","work/leisure","sds")
booktime_sds2[,1] = rep(c("no-conflict","conflict"),2)
booktime_sds2[,2] = c("leisure","leisure","work","work")
booktime_sds2

booktime_sds_orig = aggregate(x=d_orig$book_time,
                          by=list(d_orig$goal_conflict,d_orig$work),
                          FUN=sd,na.rm=TRUE)
colnames(booktime_sds_orig) = c("conflict_cond","work/leisure","sds")
booktime_sds_orig[,1] = rep(c("no-conflict","conflict"),2)
booktime_sds_orig[,2] = c("leisure","leisure","work","work")
booktime_sds_orig

# original sds shared by authors
booktime_sds_orig = data.frame(data=c(rep(c("no-conflict","conflict"),2)),
                                 c("leisure","leisure","work","work"),
                                 c(.9943082,1.2811723,.8755389,.8586794))
colnames(booktime_sds_orig) = c("conflict_cond","work/leisure","means")
booktime_sds_orig

# Get the logged book browsing time means and sds by study
mean(d_orig$book_time,na.rm=TRUE)    # 3.85
mean(d1_clean$book_time,na.rm=TRUE)  # 3.74
mean(d2_clean$book_time,na.rm=TRUE)  # 4.09

sd(d_orig$book_time,na.rm=TRUE)      # 1.04
sd(d1_clean$book_time,na.rm=TRUE)    # 1.14
sd(d2_clean$book_time,na.rm=TRUE)    # 0.95

#####

#   4.2) Get Descriptive Statistics For Raw Book Browsing Time Variable

# Get the raw book browsing time rawmeans by condition
booktime_rawmeans1 = aggregate(x=d1_clean$book_time_raw,
                            by=list(d1_clean$goal_conflict,d1_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(booktime_rawmeans1) = c("conflict_cond","work/leisure","rawmeans")
booktime_rawmeans1[,1] = rep(c("no-conflict","conflict"),2)
booktime_rawmeans1[,2] = c("leisure","leisure","work","work")
booktime_rawmeans1

booktime_rawmeans2 = aggregate(x=d2_clean$book_time_raw,
                            by=list(d2_clean$goal_conflict,d2_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(booktime_rawmeans2) = c("conflict_cond","work/leisure","rawmeans")
booktime_rawmeans2[,1] = rep(c("no-conflict","conflict"),2)
booktime_rawmeans2[,2] = c("leisure","leisure","work","work")
booktime_rawmeans2

# original means shared by authors
booktime_rawmeans_orig = data.frame(c(rep(c("no-conflict","conflict"),2)),
                                 c("leisure","leisure","work","work"),
                                 c(83.87655,70.53488,52.49998,81.32343))
colnames(booktime_rawmeans_orig) = c("conflict_cond","work/leisure","means")
booktime_rawmeans_orig


# Get the raw book browsing time raw sds by condition
booktime_rawsds1 = aggregate(x=d1_clean$book_time_raw,
                          by=list(d1_clean$goal_conflict,d1_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(booktime_rawsds1) = c("conflict_cond","work/leisure","rawsds")
booktime_rawsds1[,1] = rep(c("no-conflict","conflict"),2)
booktime_rawsds1[,2] = c("leisure","leisure","work","work")
booktime_rawsds1

booktime_rawsds2 = aggregate(x=d2_clean$book_time_raw,
                          by=list(d2_clean$goal_conflict,d2_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(booktime_rawsds2) = c("conflict_cond","work/leisure","rawsds")
booktime_rawsds2[,1] = rep(c("no-conflict","conflict"),2)
booktime_rawsds2[,2] = c("leisure","leisure","work","work")
booktime_rawsds2

# original sds shared by authors
booktime_rawsds_orig = data.frame(c(rep(c("no-conflict","conflict"),2)),
                                    c("leisure","leisure","work","work"),
                                    c(75.11605,77.51050,47.99288,60.11513))
colnames(booktime_rawsds_orig) = c("conflict_cond","work/leisure","means")
booktime_rawsds_orig


# Get the raw book browsing time means, medians, and sds by study
mean(d1_clean$book_time_raw,na.rm=TRUE)  # 71.20
mean(d2_clean$book_time_raw,na.rm=TRUE)  # 87.18
# Original study: mean = 73.17

median(d1_clean$book_time_raw,na.rm=TRUE)  # 53.58
median(d2_clean$book_time_raw,na.rm=TRUE)  # 66.74
# Original study: median = 66.74

sd(d1_clean$book_time_raw,na.rm=TRUE)    # 69.70
sd(d2_clean$book_time_raw,na.rm=TRUE)    # 72.47
# Original study: sd = 67.91

#####

#   4.3) Pre-registered Analyses Of Logged Book Browsing Time Variable

# t-test: work condition
t.test(d1_work$book_time[d1_work$goal_conflict==1],
       d1_work$book_time[d1_work$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_work$book_time[d2_work$goal_conflict==1],
       d2_work$book_time[d2_work$goal_conflict==0],
       var.equal=TRUE)

# t-test: leisure condition
t.test(d1_leisure$book_time[d1_leisure$goal_conflict==1],
       d1_leisure$book_time[d1_leisure$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_leisure$book_time[d2_leisure$goal_conflict==1],
       d2_leisure$book_time[d2_leisure$goal_conflict==0],
       var.equal=TRUE)

#####

#   4.4) Regression Analyses On Logged Book Browsing Time Variable (Not Pre-registered)

ols1 = lm(d1_clean$book_time~d1_clean$work*d1_clean$goal_conflict)
summary(ols1)

ols2 = lm(d2_clean$book_time~d2_clean$work*d2_clean$goal_conflict)
summary(ols2)

#####

#   4.5) Analyses Of Raw Book Browsing Time Variable (Not Pre-registered)

# t-test: work condition
t.test(d1_work$book_time_raw[d1_work$goal_conflict==1],
       d1_work$book_time_raw[d1_work$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_work$book_time_raw[d2_work$goal_conflict==1],
       d2_work$book_time_raw[d2_work$goal_conflict==0],
       var.equal=TRUE)


# t-test: leisure condition
t.test(d1_leisure$book_time_raw[d1_leisure$goal_conflict==1],
       d1_leisure$book_time_raw[d1_leisure$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_leisure$book_time_raw[d2_leisure$goal_conflict==1],
       d2_leisure$book_time_raw[d2_leisure$goal_conflict==0],
       var.equal=TRUE)

#####

#   4.6) Regression Analyses On Raw Book Browsing Time Variable (Not Pre-registered)

ols1 = lm(d1_clean$book_time_raw~d1_clean$work*d1_clean$goal_conflict)
summary(ols1)

ols2 = lm(d2_clean$book_time_raw~d2_clean$work*d2_clean$goal_conflict)
summary(ols2)

############################################################################################
#
# 5) Conduct Alternative Analyses Using ANOVA & Planned Contrasts (As In Original Study)
#   5.1) Analyze Replication 1

# add id variable to dataset
d1_clean$id = 1:nrow(d1_clean)

# conduct the goal conflict x frame ANOVA
anova_rep1 = aov_car(book_time~goal_conflict*work+Error(id),data=d1_clean)
anova_rep1

# compute and analyze the simple effects
simple_effects_rep1 = emmeans(anova_rep1,~goal_conflict|work)
simple_effects_rep1
pairs(simple_effects_rep1,adjust='none')

#####

#   5.2) Analyze Replication 2

# add id variable to dataset
d2_clean$id = 1:nrow(d2_clean)

# conduct the goal conflict x frame ANOVA
anova_rep2 = aov_car(book_time~goal_conflict*work+Error(id),data=d2_clean)
anova_rep2

# compute and analyze the simple effects
simple_effects_rep2 = emmeans(anova_rep2,~goal_conflict|work)
simple_effects_rep2
pairs(simple_effects_rep2,adjust='none')

############################################################################################
#
# 6) Conduct Analyses Of Manipulation Check
#   6.1) Get Descriptive Statistics

# Get the means by condition
manipck_means1 = aggregate(x=d1_clean$manipck,
                            by=list(d1_clean$goal_conflict,d1_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(manipck_means1) = c("conflict_cond","work/leisure","means")
manipck_means1[,1] = rep(c("no-conflict","conflict"),2)
manipck_means1[,2] = c("leisure","leisure","work","work")
manipck_means1

manipck_means2 = aggregate(x=d2_clean$manipck,
                            by=list(d2_clean$goal_conflict,d2_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(manipck_means2) = c("conflict_cond","work/leisure","means")
manipck_means2[,1] = rep(c("no-conflict","conflict"),2)
manipck_means2[,2] = c("leisure","leisure","work","work")
manipck_means2

# Get the manipulation check sds by condition
manipck_sds1 = aggregate(x=d1_clean$manipck,
                          by=list(d1_clean$goal_conflict,d1_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(manipck_sds1) = c("conflict_cond","work/leisure","sds")
manipck_sds1[,1] = rep(c("no-conflict","conflict"),2)
manipck_sds1[,2] = c("leisure","leisure","work","work")
manipck_sds1

manipck_sds2 = aggregate(x=d2_clean$manipck,
                          by=list(d2_clean$goal_conflict,d2_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(manipck_sds2) = c("conflict_cond","work/leisure","sds")
manipck_sds2[,1] = rep(c("no-conflict","conflict"),2)
manipck_sds2[,2] = c("leisure","leisure","work","work")
manipck_sds2

#####

#   6.2) Goal Conflict x Work/Leisure Regression

ols_manipck1 = lm(d1_clean$manipck~d1_clean$work*d1_clean$goal_conflict)
summary(ols_manipck1)

ols_manipck2 = lm(d2_clean$manipck~d2_clean$work*d2_clean$goal_conflict)
summary(ols_manipck2)

############################################################################################
#
# 7) Plotting the Book Browsing Time Results

# In each of matrices below, the six columns represent, in order, the results from the
# "Work Frame" condition of the original study, the results from the "Leisure Frame"
# condition of the original study, the results from the "Work Frame" condition of the 
# first replication, the results from the "Leisure Frame" condition of the first 
# replication, the results from the "Work Frame" condition of the second replication,
# the results from the "Leisure Frame" condition of the second replication.  
# Within a column, the first value represents the "No Conflict" condition while the 
# second value represents the "Conflict" condition.

#   7.1) Matrix of Means

booktime_means_orig1 = matrix(c(booktime_means_orig[3,3],booktime_means_orig[4,3],
                               booktime_means_orig[1,3],booktime_means_orig[2,3]),nrow=2)
booktime_means_rep1 = matrix(c(booktime_means1[3,3],booktime_means1[4,3],
                               booktime_means1[1,3],booktime_means1[2,3]),nrow=2)
booktime_means_rep2 = matrix(c(booktime_means2[3,3],booktime_means2[4,3],
                               booktime_means2[1,3],booktime_means2[2,3]),nrow=2)
booktime_means_matrix = cbind(booktime_means_orig1,booktime_means_rep1,booktime_means_rep2)

#####

#   7.2) Matrix of Standard Deviations

booktime_sds_orig1 = matrix(c(booktime_sds_orig[3,3],booktime_sds_orig[4,3],
                             booktime_sds_orig[1,3],booktime_sds_orig[2,3]),nrow=2)
booktime_sds_rep1 = matrix(c(booktime_sds1[3,3],booktime_sds1[4,3],
                             booktime_sds1[1,3],booktime_sds1[2,3]),nrow=2)
booktime_sds_rep2 = matrix(c(booktime_sds2[3,3],booktime_sds2[4,3],
                             booktime_sds2[1,3],booktime_sds2[2,3]),nrow=2)
booktime_sds_matrix = cbind(booktime_sds_orig1,booktime_sds_rep1,booktime_sds_rep2)

#####

#   7.3) Matrix of Sample Sizes
ns_orig = matrix(c(43,54,56,57),nrow=2) # from original data
ns_rep1 = matrix(c(sum(d1_clean$condition=="NOconflictXwork"),
                   sum(d1_clean$condition=="conflictXwork"),
                   sum(d1_clean$condition=="NOconflictXleisure"),
                   sum(d1_clean$condition=="conflictXleisure")),nrow=2)
ns_rep2 = matrix(c(sum(d2_clean$condition=="NOconflictXwork"),
                   sum(d2_clean$condition=="conflictXwork"),
                   sum(d2_clean$condition=="NOconflictXleisure"),
                   sum(d2_clean$condition=="conflictXleisure")),nrow=2)
ns = cbind(ns_orig,ns_rep1,ns_rep2)

#####

#   7.4) Matrix of Standard Errors
booktime_ses_matrix = booktime_sds_matrix/sqrt(ns)

#####

#   7.5) Set Graph Parameters

png("Etkin & Memmi Replication Means.png",width=10,height=6,units="in",res=300) # open .png file
par(family = "sans") # set font
par(mar=c(5.1,6.1,4.1,2.1)) # set margins
par(mgp=c(2,0.5,0)) # set axis label locations
par(mfrow=c(1,1)) # set graph to have one row and one column
adj = 1 # how much to adjust the y-axis on the graph

#####

#   7.6) Graph The Means

b = barplot(booktime_means_matrix,
            beside=T, # make it a side-by-side bar graph
            col=c("palegreen2","skyblue1"),
            cex.names=.90, # set size of axis names
            names.arg=c("Work-Frame","Leisure-Frame","Work-Frame","Leisure-Frame",
                        "Work-Frame","Leisure-Frame"),
            ylim = c(adj,6), # set y-axis range
            ylab="Logged time spent book browsing (seconds)", # label y axis
            cex.lab=.95,
            main="Original vs. Replication Results:\nTime Spent Book Browsing (Log)", # set chart title
            xpd = FALSE, # make it so that you can't draw outside of plot region
            axisnames=TRUE, # provide axis names
            las=1) # set y-axis tick mark labels so they are horizontal
abline(h=adj) # put horizontal line across x-axis
error.bar(b,booktime_means_matrix,booktime_ses_matrix) # put on error bars
legend("top",legend=c("No Goal Conflict","Goal Conflict"),
       fill=c("palegreen2","skyblue1"),ncol=1,bty="n") # add legend

# add p-values to graph
text(mean(b[,1]),max(booktime_means_matrix+.4),
     "p = .018",cex=.9) # p-value from original study
text(mean(b[,2]),max(booktime_means_matrix+.4),
     "p = .045",cex=.9) # p-value from original study
text(mean(b[,3]),max(booktime_means_matrix+.4),
     paste("p = ",f_num(t.test(d1_work$book_time[d1_work$goal_conflict==1],
                               d1_work$book_time[d1_work$goal_conflict==0],
                               var.equal=TRUE)$p.value,3),sep=""),cex=.9)
text(mean(b[,4]),max(booktime_means_matrix+.4),
     paste("p = ",f_num(t.test(d1_leisure$book_time[d1_leisure$goal_conflict==1],
                               d1_leisure$book_time[d1_leisure$goal_conflict==0],
                               var.equal=TRUE)$p.value,3),sep=""),cex=.9)
text(mean(b[,5]),max(booktime_means_matrix+.4),
     paste("p = ",f_num(t.test(d2_work$book_time[d2_work$goal_conflict==1],
                               d2_work$book_time[d2_work$goal_conflict==0],
                               var.equal=TRUE)$p.value,3),sep=""),cex=.9)
text(mean(b[,6]),max(booktime_means_matrix+.4),
     paste("p = ",f_num(t.test(d2_leisure$book_time[d2_leisure$goal_conflict==1],
                               d2_leisure$book_time[d2_leisure$goal_conflict==0],
                               var.equal=TRUE)$p.value,3),sep=""),cex=.9)

# add study labels below x-axis
mtext("Original Study (N = 210)",side=1,line=2.3,at=mean(c(b[2,1],b[1,2])))
mtext("Replication 1 (N = 1008)",side=1,line=2.3,at=mean(c(b[2,3],b[1,4])))
mtext("Replication 2 (N = 1127)",side=1,line=2.3,at=mean(c(b[2,5],b[1,6])))

# add value labels to graph
text(b,(booktime_means_matrix+adj)/2,
     labels=f_num(booktime_means_matrix,2),cex=.90)

# add vertical gray lines between studies
segments(x0=6.5,y0=0,y1=5,lty=2,col="gray")
segments(x0=12.5,y0=0,y1=5,lty=2,col="gray")

# add line about error bars
title(sub="Error bars represent +/- 1 standard error",adj=1,line=4,cex.sub=0.7,
      col.sub="gray")

dev.off()

############################################################################################
#
# 8) Conduct Exploratory Analyses of Number Of Books Variable
#   8.1) Get Descriptive Statistics For Number Of Books Variable

# Get the means by condition
numbooks_means1 = aggregate(x=d1_clean$num_books,
                            by=list(d1_clean$goal_conflict,d1_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(numbooks_means1) = c("conflict_cond","work/leisure","means")
numbooks_means1[,1] = rep(c("no-conflict","conflict"),2)
numbooks_means1[,2] = c("leisure","leisure","work","work")
numbooks_means1

numbooks_means2 = aggregate(x=d2_clean$num_books,
                            by=list(d2_clean$goal_conflict,d2_clean$work),
                            FUN=mean,na.rm=TRUE)
colnames(numbooks_means2) = c("conflict_cond","work/leisure","means")
numbooks_means2[,1] = rep(c("no-conflict","conflict"),2)
numbooks_means2[,2] = c("leisure","leisure","work","work")
numbooks_means2

# Get the sds by condition
numbooks_sds1 = aggregate(x=d1_clean$num_books,
                          by=list(d1_clean$goal_conflict,d1_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(numbooks_sds1) = c("conflict_cond","work/leisure","sds")
numbooks_sds1[,1] = rep(c("no-conflict","conflict"),2)
numbooks_sds1[,2] = c("leisure","leisure","work","work")
numbooks_sds1

numbooks_sds2 = aggregate(x=d2_clean$num_books,
                          by=list(d2_clean$goal_conflict,d2_clean$work),
                          FUN=sd,na.rm=TRUE)
colnames(numbooks_sds2) = c("conflict_cond","work/leisure","sds")
numbooks_sds2[,1] = rep(c("no-conflict","conflict"),2)
numbooks_sds2[,2] = c("leisure","leisure","work","work")
numbooks_sds2

#####

#   8.2) Exploratory Analyses Of Number of Books Variable

# t-test: work condition
t.test(d1_work$num_books[d1_work$goal_conflict==1],
       d1_work$num_books[d1_work$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_work$num_books[d2_work$goal_conflict==1],
       d2_work$num_books[d2_work$goal_conflict==0],
       var.equal=TRUE)

# t-test: leisure condition
t.test(d1_leisure$num_books[d1_leisure$goal_conflict==1],
       d1_leisure$num_books[d1_leisure$goal_conflict==0],
       var.equal=TRUE)

t.test(d2_leisure$num_books[d2_leisure$goal_conflict==1],
       d2_leisure$num_books[d2_leisure$goal_conflict==0],
       var.equal=TRUE)

#####

#   8.3) Regression Analyses On Book Number Variable

ols1 = lm(d1_clean$num_books~d1_clean$work*d1_clean$goal_conflict)
summary(ols1)

ols2 = lm(d2_clean$num_books~d2_clean$work*d2_clean$goal_conflict)
summary(ols2)

############################################################################################
#
# 9) Conduct Analyses To Assess Required Sample Sizes and Implied Power

#   9.1) Matrix of Effect Sizes

# first create a vector of Cohen's ds
d_temps = c()
for(j in 1:6) {
  
  d_temps = c(d_temps,cohen.d(means=c(booktime_means_matrix[2,j],booktime_means_matrix[1,j]),
                              sds=c(booktime_sds_matrix[2,j],booktime_sds_matrix[1,j]),
                              ns=c(ns[2,j],ns[1,j])))
}

# put those values into a matrix
# put the effect sizes of the original study in the first row, the effect sizes of
# Replication 1 in the second row, & the effect sizes of Replication 2 in the third
# row.
cohen_ds = matrix(d_temps,nrow=3,byrow=TRUE)
rownames(cohen_ds) = c("Original","Replication 1","Replication 2")
colnames(cohen_ds) = c("Work-Frame","Leisure-Frame")
cohen_ds

#####

#   9.2) Compute Required Sample Sizes Required To Detect Replication Effect Sizes

# Note: # Using sig.level = .025 and alternative = "greater" gives the probability that a
# two-sided test will yield a positive effect.

# N needed to detect leisure condition Replication 1 effect size
n_needed_best_l1 = pwr.t.test(power = .80,d=cohen_ds[2,2],sig.level=.025,
                              alternative="less")$n*2
n_needed_best_l1 # 1,342

# N needed to detect leisure condition Replication 2 effect size
n_needed_best_l2 = pwr.t.test(power = .80,d=cohen_ds[3,2],sig.level=.025,
                              alternative="less")$n*2
n_needed_best_l2 # 1,747

# N needed to detect work condition Replication 2 effect size
n_needed_best_w2 = pwr.t.test(power = .80,d=cohen_ds[3,1],sig.level=.025,
                              alternative="greater")$n*2
n_needed_best_w2 # 3,425

# Note: Since the work condition effect in Replication 1 was in the wrong direction,
# it does not make sense to compute the required Ns for that effect.

#####

#   9.3) Compute Power of Original Study To Detect Replication Effect Sizes

# Note: # Using sig.level = .025 and alternative = "greater" gives the probability that a
# two-sided test will yield a positive effect.

# Power of original study to detect leisure condition replication 1 effect size
orig_power_l1 = pwr.t.test(n=52.5,d=cohen_ds[2,2],sig.level=.025,
                           alternative="less")$power
orig_power_l1 # 11.8%

# Power of original study to detect leisure condition replication 2 effect size
orig_power_l2 = pwr.t.test(n=52.5,d=cohen_ds[3,2],sig.level=.025,
                           alternative="less")$power
orig_power_l2 # 10.0%

# Power of original study to detect work condition replication 1 effect size
orig_power_w2 = pwr.t.test(n=52.5,d=cohen_ds[2,1],sig.level=.025,
                           alternative="greater")$power
orig_power_w2 # 0.7%

# Power of original study to detect work condition replication 2 effect size
orig_power_w2 = pwr.t.test(n=52.5,d=cohen_ds[3,1],sig.level=.025,
                           alternative="greater")$power
orig_power_w2 # 7.0%

